//! Memvid v2 Python bindings
//! 
//! High-performance AI memory library with full-text and semantic search.

use pyo3::prelude::*;

mod memory;

use memory::MemvidMemory;

/// Memvid v2 Python module
#[pymodule]
fn _memvid_rs(m: &Bound<'_, PyModule>) -> PyResult<()> {
    m.add_class::<MemvidMemory>()?;
    Ok(())
}
